@@ -621,7 +621,7 @@ class Galaxy:
                             "Content-Type": "application/json",
                         }
                         if self.access_token:
-                            headers["access_token"] = self.access_token
+                            headers["access-token"] = self.access_token
                         # print(request_body)
                         try:
                             if all_feature_filter_json:
@@ -640,6 +640,7 @@ class Galaxy:
                             with requests.Session() as req_session:
                                 # print("printing before sending")
                                 # print(json.dumps(request_body))
+                                request_body["uuid"] = "false"
                                 for retry in range(MAX_RETRIES):
                                     r = req_session.post(
                                         url=f"{self.hostname}v1/snapshot/",
@@ -805,7 +806,7 @@ class Galaxy:
 
         headers = {"accept": "application/json", "Content-Type": "application/json"}
         if self.access_token:
-            headers["access_token"] = self.access_token
+            headers["access-token"] = self.access_token
         # print(request_body)
         try:
             with requests.Session() as req_session:
